@@ -15,6 +15,7 @@ from ftw.simplelayout.staging.interfaces import IBaseline
 from ftw.simplelayout.staging.interfaces import IStaging
 from ftw.simplelayout.staging.interfaces import IWorkingCopy
 from ftw.simplelayout.utils import unrestricted_uuidToObject
+from ftw.simplelayout.utils import IS_PLONE_5
 from operator import methodcaller
 from persistent.list import PersistentList
 from persistent.mapping import PersistentMapping
@@ -39,13 +40,15 @@ from zope.lifecycleevent.interfaces import IObjectCopiedEvent
 from zope.schema import getFieldsInOrder
 import pkg_resources
 
+EVENT_SUPPORT = False
 try:
     pkg_resources.get_distribution('plone.app.event')
 except pkg_resources.DistributionNotFound:
-    EVENT_SUPPORT = False
+    pass
 else:
-    EVENT_SUPPORT = True
-    from plone.app.event.dx.behaviors import EventBasic
+    if not IS_PLONE_5:
+        EVENT_SUPPORT = True
+        from plone.app.event.dx.behaviors import EventBasic
 
 
 try:
@@ -293,7 +296,6 @@ class Staging(object):
         uuid_map = uuid_map or {}
         uuid_map[IUUID(source)] = IUUID(target)
         target_children_map = {IUUID(obj): obj for obj in self._get_children(target, condition)}
-        source_ids = source.objectIds()
         self._copy_field_values(source, target)
         self._purge_scales(target)
         self._update_simplelayout_block_state(source, target)
@@ -304,12 +306,11 @@ class Staging(object):
                 target_child = target_children_map.pop(target_uid)
                 self._apply_children(source_child, target_child, uuid_map=uuid_map)
             else:
-                target_child = self._move_new_obj(source_child, target)
+                target_child = self._copy_new_obj(source_child, target)
                 uuid_map[IUUID(source_child)] = IUUID(target_child)
 
-        target.moveObjectsToTop(source_ids)
+        target.moveObjectsToTop(source.objectIds())
         target.manage_delObjects(map(methodcaller('getId'), target_children_map.values()))
-        target.reindexObject()
         return uuid_map
 
     def _update_simplelayout_page_state(self, working_copy, baseline, uuid_map):
@@ -388,6 +389,9 @@ class Staging(object):
 
     def _copy_dx_field_values(self, source, target):
         for name, field, schemata in self._iter_fields(source.portal_type):
+            if name == 'id':
+                # never re-set the id.
+                continue
             source_storage = schemata(source)
             target_storage = schemata(target)
             value = getattr(source_storage, name)
@@ -423,8 +427,8 @@ class Staging(object):
         for schema in getAdditionalSchemata(portal_type=portal_type):
             yield schema
 
-    def _move_new_obj(self, obj, new_parent):
-        clipboard = aq_parent(aq_inner(obj)).manage_cutObjects([obj.getId()])
+    def _copy_new_obj(self, obj, new_parent):
+        clipboard = aq_parent(aq_inner(obj)).manage_copyObjects([obj.getId()])
         info = new_parent.manage_pasteObjects(clipboard)
         return new_parent.get(info[0]['new_id'])
 
